@@ -14,7 +14,7 @@
  *                         All rights reserved.
  * Copyright (c) 2014-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2016-2021 IBM Corporation.  All rights reserved.
- * Copyright (c) 2021-2023 Nanook Consulting  All rights reserved.
+ * Copyright (c) 2021-2024 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -540,7 +540,6 @@ prte_proc_t *prte_rmaps_base_setup_proc(prte_job_t *jdata,
     proc = PMIX_NEW(prte_proc_t);
     /* set the jobid */
     PMIX_LOAD_NSPACE(proc->name.nspace, jdata->nspace);
-    proc->job = jdata;
     /* flag the proc as ready for launch */
     proc->state = PRTE_PROC_STATE_INIT;
     proc->app_idx = idx;
@@ -636,27 +635,18 @@ int prte_rmaps_base_get_ncpus(prte_node_t *node,
 {
     int ncpus;
 
+    if (NULL == options->job_cpuset) {
+        hwloc_bitmap_copy(prte_rmaps_base.available, node->available);
+    } else {
+        hwloc_bitmap_and(prte_rmaps_base.available, node->available, options->job_cpuset);
+    }
+    if (NULL != obj) {
 #if HWLOC_API_VERSION < 0x20000
-    hwloc_obj_t root;
-    root = hwloc_get_root_obj(node->topology->topo);
-    if (NULL == options->job_cpuset) {
-        hwloc_bitmap_copy(prte_rmaps_base.available, root->allowed_cpuset);
-    } else {
-        hwloc_bitmap_and(prte_rmaps_base.available, root->allowed_cpuset, options->job_cpuset);
-    }
-    if (NULL != obj) {
         hwloc_bitmap_and(prte_rmaps_base.available, prte_rmaps_base.available, obj->allowed_cpuset);
-    }
 #else
-    if (NULL == options->job_cpuset) {
-        hwloc_bitmap_copy(prte_rmaps_base.available, hwloc_topology_get_allowed_cpuset(node->topology->topo));
-    } else {
-        hwloc_bitmap_and(prte_rmaps_base.available, hwloc_topology_get_allowed_cpuset(node->topology->topo), options->job_cpuset);
-    }
-    if (NULL != obj) {
         hwloc_bitmap_and(prte_rmaps_base.available, prte_rmaps_base.available, obj->cpuset);
-    }
 #endif
+    }
     if (options->use_hwthreads) {
         ncpus = hwloc_bitmap_weight(prte_rmaps_base.available);
     } else {
@@ -669,6 +659,7 @@ int prte_rmaps_base_get_ncpus(prte_node_t *node,
          */
         ncpus = hwloc_get_nbobjs_inside_cpuset_by_type(node->topology->topo, prte_rmaps_base.available, HWLOC_OBJ_CORE);
     }
+
     return ncpus;
 }
 
