@@ -18,7 +18,7 @@
  *                         All rights reserved.
  * Copyright (c) 2014-2019 Research Organization for Information Science
  *                         and Technology (RIST).  All rights reserved.
- * Copyright (c) 2021-2023 Nanook Consulting  All rights reserved.
+ * Copyright (c) 2021-2024 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -208,7 +208,6 @@ static void interim(int sd, short args, void *cbdata)
     bool flag;
     size_t m, n;
     uint16_t u16;
-    pmix_rank_t rank;
     prte_rmaps_options_t options;
     prte_schizo_base_module_t *schizo;
     PRTE_HIDE_UNUSED_PARAMS(sd, args);
@@ -242,6 +241,7 @@ static void interim(int sd, short args, void *cbdata)
     for (n = 0; n < cd->napps; n++) {
         papp = &cd->apps[n];
         app = PMIX_NEW(prte_app_context_t);
+        app->job = (struct prte_job_t*)jdata;
         app->idx = pmix_pointer_array_add(jdata->apps, app);
         jdata->num_apps++;
         if (NULL != papp->cmd) {
@@ -861,7 +861,6 @@ int pmix_server_spawn_fn(const pmix_proc_t *proc, const pmix_info_t job_info[],
     cd->spcbfunc = cbfunc;
     cd->cbdata = cbdata;
     prte_event_set(prte_event_base, &cd->ev, -1, PRTE_EV_WRITE, interim, cd);
-    prte_event_set_priority(&cd->ev, PRTE_MSG_PRI);
     PMIX_POST_OBJECT(cd);
     prte_event_active(&cd->ev, PRTE_EV_WRITE, 1);
     return PRTE_SUCCESS;
@@ -1287,7 +1286,6 @@ pmix_status_t pmix_server_connect_fn(const pmix_proc_t procs[], size_t nprocs,
     op->cbfunc = cbfunc;
     op->cbdata = cbdata;
     prte_event_set(prte_event_base, &(op->ev), -1, PRTE_EV_WRITE, _cnct, op);
-    prte_event_set_priority(&(op->ev), PRTE_MSG_PRI);
     PMIX_POST_OBJECT(op);
     prte_event_active(&(op->ev), PRTE_EV_WRITE, 1);
 
