@@ -36,7 +36,7 @@ mca_coll_hcoll_component_t mca_coll_hcoll_component = {
        about the component itfca */
     {
         .collm_version = {
-            MCA_COLL_BASE_VERSION_2_0_0,
+            MCA_COLL_BASE_VERSION_2_4_0,
 
             /* Component name and version */
             .mca_component_name = "hcoll",
@@ -170,7 +170,7 @@ static int hcoll_register(void)
                   0));
 
     CHECK(reg_int("datatype_fallback",NULL,
-                  "[1|0|] Enable/Disable user defined dattypes fallback",
+                  "[1|0|] Enable/Disable user defined datatypes fallback",
                   1,
                   &mca_coll_hcoll_component.hcoll_datatype_fallback,
                   0));
@@ -209,29 +209,10 @@ static int hcoll_open(void)
 {
     mca_coll_hcoll_component_t *cm;
     cm  = &mca_coll_hcoll_component;
-
     mca_coll_hcoll_output = opal_output_open(NULL);
     opal_output_set_verbosity(mca_coll_hcoll_output, cm->hcoll_verbose);
-
     hcoll_rte_fns_setup();
-
     cm->libhcoll_initialized = false;
-
-    (void)mca_base_framework_open(&opal_memory_base_framework, 0);
-
-    /* Register memory hooks */
-    if ((OPAL_MEMORY_FREE_SUPPORT | OPAL_MEMORY_MUNMAP_SUPPORT) ==
-        ((OPAL_MEMORY_FREE_SUPPORT | OPAL_MEMORY_MUNMAP_SUPPORT) &
-         opal_mem_hooks_support_level()))
-    {
-        setenv("MXM_HCOLL_MEM_ON_DEMAND_MAP", "y", 0);
-        HCOL_VERBOSE(1, "Enabling on-demand memory mapping");
-        cm->using_mem_hooks = 1;
-    } else {
-        HCOL_VERBOSE(1, "Disabling on-demand memory mapping");
-        cm->using_mem_hooks = 0;
-    }
-
     return OMPI_SUCCESS;
 }
 
