@@ -6,15 +6,15 @@
  * Copyright (c) 2004-2005 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
- * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
+ * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
  * Copyright (c) 2011-2012 FUJITSU LIMITED.  All rights reserved.
  * $COPYRIGHT$
- * 
+ *
  * Additional copyrights may follow
- * 
+ *
  * $HEADER$
  */
 
@@ -28,7 +28,7 @@ BEGIN_C_DECLS
 
 typedef struct msg_rule_s {
     /* paranoid / debug */
-    int mpi_comsize;  /* which MPI comm size this is is for */
+    int mpi_comsize;  /* which MPI comm size is this for */
 
     /* paranoid / debug */
     int alg_rule_id; /* unique alg rule id */
@@ -41,14 +41,14 @@ typedef struct msg_rule_s {
     /* RESULT */
     int result_alg;              /* result algorithm to use */
     int result_topo_faninout;    /* result topology fan in/out to use (if applicable) */
-    long result_segsize;         /* result segment size to use */ 
+    long result_segsize;         /* result segment size to use */
     int result_max_requests;     /* maximum number of outstanding requests (if applicable) */
 } ompi_coll_msg_rule_t;
 
 
 typedef struct com_rule_s {
     /* paranoid / debug */
-    int mpi_comsize;  /* which MPI comm size this is is for */
+    int mpi_comsize;  /* which MPI comm size is this for */
 
     /* paranoid / debug */
     int alg_rule_id; /* unique alg rule id */
@@ -94,8 +94,8 @@ int ompi_coll_tuned_free_all_rules (ompi_coll_alg_rule_t* alg_p, int n_algs);
 
 ompi_coll_com_rule_t* ompi_coll_tuned_get_com_rule_ptr (ompi_coll_alg_rule_t* rules, int alg_id, int mpi_comsize);
 
-int ompi_coll_tuned_get_target_method_params (ompi_coll_com_rule_t* base_com_rule, size_t mpi_msgsize, 
-                                              int* result_topo_faninout, int* result_segsize, 
+int ompi_coll_tuned_get_target_method_params (ompi_coll_com_rule_t* base_com_rule, size_t mpi_msgsize,
+                                              int* result_topo_faninout, int* result_segsize,
                                               int* max_requests);
 
 
