@@ -3,9 +3,9 @@
  *                         All rights reserved.
  * Copyright (c) 2013 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
- * 
+ *
  * Additional copyrights may follow
- * 
+ *
  * $HEADER$
  */
 
@@ -16,12 +16,18 @@
 #include "oshmem/mca/spml/spml.h"
 #include "ompi/datatype/ompi_datatype.h"
 
+#if OSHMEM_PROFILING
+#include "oshmem/shmem/fortran/pbindings.h"
+SHMEM_GENERATE_WEAK_BINDINGS(SHMEM_INT8_WAIT, shmem_int8_wait)
+#include "oshmem/shmem/fortran/profile-defines.h"
+#endif
+
 SHMEM_GENERATE_FORTRAN_BINDINGS_SUB (void,
         SHMEM_INT8_WAIT,
         shmem_int8_wait_,
         shmem_int8_wait__,
         shmem_int8_wait_f,
-        (ompi_fortran_integer8_t *var, ompi_fortran_integer8_t *value), 
+        (ompi_fortran_integer8_t *var, ompi_fortran_integer8_t *value),
         (var,value))
 
 void shmem_int8_wait_f(ompi_fortran_integer8_t *var, ompi_fortran_integer8_t *value)
